@@ -1,9 +1,11 @@
+{-# OPTIONS_GHC -Wno-missing-signatures #-}
+
 module Main.Gen where
 
 import qualified Data.HashSet as HashSet
 import qualified Data.List as List
 import qualified Data.Text as Text
-import Hedgehog (Gen, MonadGen)
+import Hedgehog (Gen)
 import Hedgehog.Gen
 import qualified Hedgehog.Range as Range
 import PostgresqlSyntax.Ast
@@ -13,9 +15,9 @@ import Prelude hiding (bit, bool, filter, fromList, maybe, sortBy)
 
 -- * Generic
 
-inSet _set = filter (flip HashSet.member _set)
+inSet set = filter (flip HashSet.member set)
 
-notInSet _set = filter (not . flip HashSet.member _set)
+notInSet set = filter (not . flip HashSet.member set)
 
 -- * Statements
 
@@ -24,9 +26,14 @@ preparableStmt =
     [ SelectPreparableStmt <$> selectStmt,
       InsertPreparableStmt <$> insertStmt,
       UpdatePreparableStmt <$> updateStmt,
-      DeletePreparableStmt <$> deleteStmt
+      DeletePreparableStmt <$> deleteStmt,
+      CallPreparableStmt <$> callStmt
     ]
 
+-- * Call
+
+callStmt = CallStmt <$> funcApplication
+
 -- * Insert
 
 insertStmt = InsertStmt <$> maybe withClause <*> insertTarget <*> insertRest <*> maybe onConflict <*> maybe returningClause
@@ -100,8 +107,8 @@ terminalSelectNoParens =
 
 -- ** selectWithParens
 
-selectWithParens = sized $ \_size ->
-  if _size <= 1
+selectWithParens = sized $ \size ->
+  if size <= 1
     then discard
     else
       frequency
@@ -139,8 +146,8 @@ tableSimpleSelect = TableSimpleSelect <$> relationExpr
 
 valuesSimpleSelect = ValuesSimpleSelect <$> valuesClause
 
-binSimpleSelect _leftSelect =
-  BinSimpleSelect <$> selectBinOp <*> pure _leftSelect <*> maybe allOrDistinct <*> small selectClause
+binSimpleSelect leftSelect =
+  BinSimpleSelect <$> selectBinOp <*> pure leftSelect <*> maybe allOrDistinct <*> small selectClause
 
 terminalSimpleSelect = pure (NormalSimpleSelect Nothing Nothing Nothing Nothing Nothing Nothing Nothing)
 
@@ -518,8 +525,6 @@ cExpr =
       GroupingCExpr <$> exprList
     ]
 
--- **
-
 caseExpr = CaseExpr <$> maybe aExpr <*> whenClauseList <*> maybe aExpr
 
 whenClauseList = nonEmpty (Range.exponential 1 7) whenClause
@@ -533,8 +538,8 @@ inExpr =
     ]
 
 arrayExpr =
-  small $
-    choice
+  small
+    $ choice
       [ ExprListArrayExpr <$> exprList,
         ArrayExprListArrayExpr <$> arrayExprList,
         pure EmptyArrayExpr
@@ -673,7 +678,7 @@ qualAllOp =
     ]
 
 op = do
-  a <- text (Range.exponential 1 7) (element "+-*/<>=~!@#%^&|`?")
+  a <- text (Range.exponential 1 7) (listElement "+-*/<>=~!@#%^&|`?")
   case Validation.op a of
     Nothing -> return a
     _ -> discard
@@ -736,8 +741,8 @@ aexprConst =
     [ IAexprConst <$> iconst,
       FAexprConst <$> fconst,
       SAexprConst <$> sconst,
-      BAexprConst <$> text (Range.exponential 1 100) (element "01"),
-      XAexprConst <$> text (Range.exponential 1 100) (element "0123456789abcdefABCDEF"),
+      BAexprConst <$> text (Range.exponential 1 100) (listElement "01"),
+      XAexprConst <$> text (Range.exponential 1 100) (listElement "0123456789abcdefABCDEF"),
       FuncAexprConst <$> funcName <*> maybe funcConstArgs <*> sconst,
       ConstTypenameAexprConst <$> constTypename <*> sconst,
       StringIntervalAexprConst <$> sconst <*> maybe interval,
@@ -817,8 +822,8 @@ sconst = text (Range.exponential 0 1000) unicode
 iconstOrFconst = choice [Left <$> iconst <|> Right <$> fconst]
 
 fconst =
-  filter (\a -> fromIntegral (round a) /= a) $
-    realFrac_ (Range.exponentialFloat 0 309457394857984375983475943)
+  filter (\a -> fromIntegral (round a) /= a)
+    $ realFrac_ (Range.exponentialFloat 0 309457394857984375983475943)
 
 iconst = integral (Range.exponential 0 maxBound)
 
@@ -940,3 +945,8 @@ class_ = anyName
 ascDesc = enumBounded
 
 nullsOrder = enumBounded
+
+-- * Helpers
+
+listElement :: [a] -> Gen a
+listElement = element
