@@ -5,7 +5,7 @@
 -- For reasoning see the docs of the parsing module of this project.
 module PostgresqlSyntax.Ast where
 
-import PostgresqlSyntax.Prelude hiding (Op, Order)
+import PostgresqlSyntax.Prelude
 
 -- * Statement
 
@@ -17,12 +17,20 @@ import PostgresqlSyntax.Prelude hiding (Op, Order)
 --   |  InsertStmt
 --   |  UpdateStmt
 --   |  DeleteStmt
+--   |  CallStmt
 -- @
 data PreparableStmt
   = SelectPreparableStmt SelectStmt
   | InsertPreparableStmt InsertStmt
   | UpdatePreparableStmt UpdateStmt
   | DeletePreparableStmt DeleteStmt
+  | CallPreparableStmt CallStmt
+  deriving (Show, Generic, Eq, Ord)
+
+-- * Call
+
+newtype CallStmt
+  = CallStmt FuncApplication
   deriving (Show, Generic, Eq, Ord)
 
 -- * Insert
@@ -764,8 +772,16 @@ data TableRef
 -- | ONLY '(' qualified_name ')'
 -- @
 data RelationExpr
-  = SimpleRelationExpr QualifiedName Bool
-  | OnlyRelationExpr QualifiedName Bool
+  = SimpleRelationExpr
+      -- | Name.
+      QualifiedName
+      -- | Is asterisk present?
+      Bool
+  | OnlyRelationExpr
+      -- | Name.
+      QualifiedName
+      -- | Are parentheses present?
+      Bool
   deriving (Show, Generic, Eq, Ord)
 
 -- |
@@ -1146,8 +1162,6 @@ data CExpr
   | GroupingCExpr ExprList
   deriving (Show, Generic, Eq, Ord)
 
--- **
-
 -- |
 -- ==== References
 -- @
@@ -1967,13 +1981,13 @@ data IndirectionEl
 -- @
 data Typename
   = Typename
+      -- | SETOF
       Bool
-      -- ^ SETOF
       SimpleTypename
+      -- | Question mark
       Bool
-      -- ^ Question mark
+      -- | Array dimensions possibly followed by a question mark
       (Maybe (TypenameArrayDimensions, Bool))
-      -- ^ Array dimensions possibly followed by a question mark
   deriving (Show, Generic, Eq, Ord)
 
 -- |
